Learn R Programming

perccalc (version 1.0.5)

pisa_2012: Mathematics test scores of Spain, Germany and Estonia in the PISA 2012 test

Description

A dataset containing the test scores and other household information of students from Spain, Germany and Estonia from the PISA 2012 test.

Usage

pisa_2012

Arguments

Format

A data frame with 35093 rows and 10 variables:

year

Year of the survey

CNT

Long country names

STIDSTD

Unique student id

father_edu

The father's highest achieved degree in the ISCED scale

household_income

The household's total income in categories

avg_math

The average math test score out of the 5 plausible values in Mathematics